# coding: utf-8

"""
    Onshape REST API

    The Onshape REST API consumed by all clients.  # noqa: E501

    OpenAPI spec version: 1.96
    Contact: api-support@onshape.zendesk.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from onshape_client.api_client import ApiClient


class AssembliesApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def add_feature(self, did, wvm, wvmid, eid, **kwargs):  # noqa: E501
        """add_feature  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.add_feature(did, wvm, wvmid, eid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str did: (required)
        :param str wvm: (required)
        :param str wvmid: (required)
        :param str eid: (required)
        :param str body:
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.add_feature_with_http_info(did, wvm, wvmid, eid, **kwargs)  # noqa: E501
        else:
            (data) = self.add_feature_with_http_info(did, wvm, wvmid, eid, **kwargs)  # noqa: E501
            return data

    def add_feature_with_http_info(self, did, wvm, wvmid, eid, **kwargs):  # noqa: E501
        """add_feature  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.add_feature_with_http_info(did, wvm, wvmid, eid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str did: (required)
        :param str wvm: (required)
        :param str wvmid: (required)
        :param str eid: (required)
        :param str body:
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['did', 'wvm', 'wvmid', 'eid', 'body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method add_feature" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'did' is set
        if ('did' not in local_var_params or
                local_var_params['did'] is None):
            raise ValueError("Missing the required parameter `did` when calling `add_feature`")  # noqa: E501
        # verify the required parameter 'wvm' is set
        if ('wvm' not in local_var_params or
                local_var_params['wvm'] is None):
            raise ValueError("Missing the required parameter `wvm` when calling `add_feature`")  # noqa: E501
        # verify the required parameter 'wvmid' is set
        if ('wvmid' not in local_var_params or
                local_var_params['wvmid'] is None):
            raise ValueError("Missing the required parameter `wvmid` when calling `add_feature`")  # noqa: E501
        # verify the required parameter 'eid' is set
        if ('eid' not in local_var_params or
                local_var_params['eid'] is None):
            raise ValueError("Missing the required parameter `eid` when calling `add_feature`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'did' in local_var_params:
            path_params['did'] = local_var_params['did']  # noqa: E501
        if 'wvm' in local_var_params:
            path_params['wvm'] = local_var_params['wvm']  # noqa: E501
        if 'wvmid' in local_var_params:
            path_params['wvmid'] = local_var_params['wvmid']  # noqa: E501
        if 'eid' in local_var_params:
            path_params['eid'] = local_var_params['eid']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in local_var_params:
            body_params = local_var_params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/vnd.onshape.v1+json;charset=UTF-8; qs=0.1', 'application/json;charset=UTF-8; qs=0.9'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json;charset=UTF-8'])  # noqa: E501

        # Authentication setting
        auth_settings = ['OAuth2']  # noqa: E501

        return self.api_client.call_api(
            '/api/assemblies/d/{did}/{wvm}/{wvmid}/e/{eid}/features', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def create_assembly(self, did, wid, bt_model_element_params, **kwargs):  # noqa: E501
        """create_assembly  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_assembly(did, wid, bt_model_element_params, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str did: (required)
        :param str wid: (required)
        :param BTModelElementParams bt_model_element_params: (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.create_assembly_with_http_info(did, wid, bt_model_element_params, **kwargs)  # noqa: E501
        else:
            (data) = self.create_assembly_with_http_info(did, wid, bt_model_element_params, **kwargs)  # noqa: E501
            return data

    def create_assembly_with_http_info(self, did, wid, bt_model_element_params, **kwargs):  # noqa: E501
        """create_assembly  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_assembly_with_http_info(did, wid, bt_model_element_params, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str did: (required)
        :param str wid: (required)
        :param BTModelElementParams bt_model_element_params: (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['did', 'wid', 'bt_model_element_params']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method create_assembly" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'did' is set
        if ('did' not in local_var_params or
                local_var_params['did'] is None):
            raise ValueError("Missing the required parameter `did` when calling `create_assembly`")  # noqa: E501
        # verify the required parameter 'wid' is set
        if ('wid' not in local_var_params or
                local_var_params['wid'] is None):
            raise ValueError("Missing the required parameter `wid` when calling `create_assembly`")  # noqa: E501
        # verify the required parameter 'bt_model_element_params' is set
        if ('bt_model_element_params' not in local_var_params or
                local_var_params['bt_model_element_params'] is None):
            raise ValueError("Missing the required parameter `bt_model_element_params` when calling `create_assembly`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'did' in local_var_params:
            path_params['did'] = local_var_params['did']  # noqa: E501
        if 'wid' in local_var_params:
            path_params['wid'] = local_var_params['wid']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'bt_model_element_params' in local_var_params:
            body_params = local_var_params['bt_model_element_params']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/vnd.onshape.v1+json;charset=UTF-8; qs=0.1', 'application/json;charset=UTF-8; qs=0.9'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json;charset=UTF-8'])  # noqa: E501

        # Authentication setting
        auth_settings = ['OAuth2']  # noqa: E501

        return self.api_client.call_api(
            '/api/assemblies/d/{did}/w/{wid}', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def create_instance1(self, did, wid, eid, bt_assembly_instance_definition_params, **kwargs):  # noqa: E501
        """create_instance1  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_instance1(did, wid, eid, bt_assembly_instance_definition_params, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str did: (required)
        :param str wid: (required)
        :param str eid: (required)
        :param BTAssemblyInstanceDefinitionParams bt_assembly_instance_definition_params: (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.create_instance1_with_http_info(did, wid, eid, bt_assembly_instance_definition_params, **kwargs)  # noqa: E501
        else:
            (data) = self.create_instance1_with_http_info(did, wid, eid, bt_assembly_instance_definition_params, **kwargs)  # noqa: E501
            return data

    def create_instance1_with_http_info(self, did, wid, eid, bt_assembly_instance_definition_params, **kwargs):  # noqa: E501
        """create_instance1  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_instance1_with_http_info(did, wid, eid, bt_assembly_instance_definition_params, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str did: (required)
        :param str wid: (required)
        :param str eid: (required)
        :param BTAssemblyInstanceDefinitionParams bt_assembly_instance_definition_params: (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['did', 'wid', 'eid', 'bt_assembly_instance_definition_params']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method create_instance1" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'did' is set
        if ('did' not in local_var_params or
                local_var_params['did'] is None):
            raise ValueError("Missing the required parameter `did` when calling `create_instance1`")  # noqa: E501
        # verify the required parameter 'wid' is set
        if ('wid' not in local_var_params or
                local_var_params['wid'] is None):
            raise ValueError("Missing the required parameter `wid` when calling `create_instance1`")  # noqa: E501
        # verify the required parameter 'eid' is set
        if ('eid' not in local_var_params or
                local_var_params['eid'] is None):
            raise ValueError("Missing the required parameter `eid` when calling `create_instance1`")  # noqa: E501
        # verify the required parameter 'bt_assembly_instance_definition_params' is set
        if ('bt_assembly_instance_definition_params' not in local_var_params or
                local_var_params['bt_assembly_instance_definition_params'] is None):
            raise ValueError("Missing the required parameter `bt_assembly_instance_definition_params` when calling `create_instance1`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'did' in local_var_params:
            path_params['did'] = local_var_params['did']  # noqa: E501
        if 'wid' in local_var_params:
            path_params['wid'] = local_var_params['wid']  # noqa: E501
        if 'eid' in local_var_params:
            path_params['eid'] = local_var_params['eid']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'bt_assembly_instance_definition_params' in local_var_params:
            body_params = local_var_params['bt_assembly_instance_definition_params']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/vnd.onshape.v1+json;charset=UTF-8; qs=0.1', 'application/json;charset=UTF-8; qs=0.9'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json;charset=UTF-8'])  # noqa: E501

        # Authentication setting
        auth_settings = ['OAuth2']  # noqa: E501

        return self.api_client.call_api(
            '/api/assemblies/d/{did}/w/{wid}/e/{eid}/instances', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def delete_feature2(self, did, wid, eid, fid, **kwargs):  # noqa: E501
        """delete_feature2  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_feature2(did, wid, eid, fid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str did: (required)
        :param str wid: (required)
        :param str eid: (required)
        :param str fid: (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.delete_feature2_with_http_info(did, wid, eid, fid, **kwargs)  # noqa: E501
        else:
            (data) = self.delete_feature2_with_http_info(did, wid, eid, fid, **kwargs)  # noqa: E501
            return data

    def delete_feature2_with_http_info(self, did, wid, eid, fid, **kwargs):  # noqa: E501
        """delete_feature2  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_feature2_with_http_info(did, wid, eid, fid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str did: (required)
        :param str wid: (required)
        :param str eid: (required)
        :param str fid: (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['did', 'wid', 'eid', 'fid']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method delete_feature2" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'did' is set
        if ('did' not in local_var_params or
                local_var_params['did'] is None):
            raise ValueError("Missing the required parameter `did` when calling `delete_feature2`")  # noqa: E501
        # verify the required parameter 'wid' is set
        if ('wid' not in local_var_params or
                local_var_params['wid'] is None):
            raise ValueError("Missing the required parameter `wid` when calling `delete_feature2`")  # noqa: E501
        # verify the required parameter 'eid' is set
        if ('eid' not in local_var_params or
                local_var_params['eid'] is None):
            raise ValueError("Missing the required parameter `eid` when calling `delete_feature2`")  # noqa: E501
        # verify the required parameter 'fid' is set
        if ('fid' not in local_var_params or
                local_var_params['fid'] is None):
            raise ValueError("Missing the required parameter `fid` when calling `delete_feature2`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'did' in local_var_params:
            path_params['did'] = local_var_params['did']  # noqa: E501
        if 'wid' in local_var_params:
            path_params['wid'] = local_var_params['wid']  # noqa: E501
        if 'eid' in local_var_params:
            path_params['eid'] = local_var_params['eid']  # noqa: E501
        if 'fid' in local_var_params:
            path_params['fid'] = local_var_params['fid']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/vnd.onshape.v1+json;charset=UTF-8; qs=0.1', 'application/json;charset=UTF-8; qs=0.9'])  # noqa: E501

        # Authentication setting
        auth_settings = ['OAuth2']  # noqa: E501

        return self.api_client.call_api(
            '/api/assemblies/d/{did}/w/{wid}/e/{eid}/features/featureid/{fid}', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def delete_instance1(self, did, eid, wid, nid, **kwargs):  # noqa: E501
        """delete_instance1  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_instance1(did, eid, wid, nid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str did: (required)
        :param str eid: (required)
        :param str wid: (required)
        :param str nid: (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.delete_instance1_with_http_info(did, eid, wid, nid, **kwargs)  # noqa: E501
        else:
            (data) = self.delete_instance1_with_http_info(did, eid, wid, nid, **kwargs)  # noqa: E501
            return data

    def delete_instance1_with_http_info(self, did, eid, wid, nid, **kwargs):  # noqa: E501
        """delete_instance1  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_instance1_with_http_info(did, eid, wid, nid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str did: (required)
        :param str eid: (required)
        :param str wid: (required)
        :param str nid: (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['did', 'eid', 'wid', 'nid']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method delete_instance1" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'did' is set
        if ('did' not in local_var_params or
                local_var_params['did'] is None):
            raise ValueError("Missing the required parameter `did` when calling `delete_instance1`")  # noqa: E501
        # verify the required parameter 'eid' is set
        if ('eid' not in local_var_params or
                local_var_params['eid'] is None):
            raise ValueError("Missing the required parameter `eid` when calling `delete_instance1`")  # noqa: E501
        # verify the required parameter 'wid' is set
        if ('wid' not in local_var_params or
                local_var_params['wid'] is None):
            raise ValueError("Missing the required parameter `wid` when calling `delete_instance1`")  # noqa: E501
        # verify the required parameter 'nid' is set
        if ('nid' not in local_var_params or
                local_var_params['nid'] is None):
            raise ValueError("Missing the required parameter `nid` when calling `delete_instance1`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'did' in local_var_params:
            path_params['did'] = local_var_params['did']  # noqa: E501
        if 'eid' in local_var_params:
            path_params['eid'] = local_var_params['eid']  # noqa: E501
        if 'wid' in local_var_params:
            path_params['wid'] = local_var_params['wid']  # noqa: E501
        if 'nid' in local_var_params:
            path_params['nid'] = local_var_params['nid']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/vnd.onshape.v1+json;charset=UTF-8; qs=0.1', 'application/json;charset=UTF-8; qs=0.9'])  # noqa: E501

        # Authentication setting
        auth_settings = ['OAuth2']  # noqa: E501

        return self.api_client.call_api(
            '/api/assemblies/d/{did}/w/{wid}/e/{eid}/instance/nodeid/{nid}', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_assembly_definition1(self, did, wvm, wvmid, eid, **kwargs):  # noqa: E501
        """get_assembly_definition1  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_assembly_definition1(did, wvm, wvmid, eid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str did: (required)
        :param str wvm: (required)
        :param str wvmid: (required)
        :param str eid: (required)
        :param str link_document_id:
        :param bool include_mate_features:
        :param bool include_non_solids:
        :param bool include_mate_connectors:
        :param str configuration:
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_assembly_definition1_with_http_info(did, wvm, wvmid, eid, **kwargs)  # noqa: E501
        else:
            (data) = self.get_assembly_definition1_with_http_info(did, wvm, wvmid, eid, **kwargs)  # noqa: E501
            return data

    def get_assembly_definition1_with_http_info(self, did, wvm, wvmid, eid, **kwargs):  # noqa: E501
        """get_assembly_definition1  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_assembly_definition1_with_http_info(did, wvm, wvmid, eid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str did: (required)
        :param str wvm: (required)
        :param str wvmid: (required)
        :param str eid: (required)
        :param str link_document_id:
        :param bool include_mate_features:
        :param bool include_non_solids:
        :param bool include_mate_connectors:
        :param str configuration:
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['did', 'wvm', 'wvmid', 'eid', 'link_document_id', 'include_mate_features', 'include_non_solids', 'include_mate_connectors', 'configuration']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_assembly_definition1" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'did' is set
        if ('did' not in local_var_params or
                local_var_params['did'] is None):
            raise ValueError("Missing the required parameter `did` when calling `get_assembly_definition1`")  # noqa: E501
        # verify the required parameter 'wvm' is set
        if ('wvm' not in local_var_params or
                local_var_params['wvm'] is None):
            raise ValueError("Missing the required parameter `wvm` when calling `get_assembly_definition1`")  # noqa: E501
        # verify the required parameter 'wvmid' is set
        if ('wvmid' not in local_var_params or
                local_var_params['wvmid'] is None):
            raise ValueError("Missing the required parameter `wvmid` when calling `get_assembly_definition1`")  # noqa: E501
        # verify the required parameter 'eid' is set
        if ('eid' not in local_var_params or
                local_var_params['eid'] is None):
            raise ValueError("Missing the required parameter `eid` when calling `get_assembly_definition1`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'did' in local_var_params:
            path_params['did'] = local_var_params['did']  # noqa: E501
        if 'wvm' in local_var_params:
            path_params['wvm'] = local_var_params['wvm']  # noqa: E501
        if 'wvmid' in local_var_params:
            path_params['wvmid'] = local_var_params['wvmid']  # noqa: E501
        if 'eid' in local_var_params:
            path_params['eid'] = local_var_params['eid']  # noqa: E501

        query_params = []
        if 'link_document_id' in local_var_params:
            query_params.append(('linkDocumentId', local_var_params['link_document_id']))  # noqa: E501
        if 'include_mate_features' in local_var_params:
            query_params.append(('includeMateFeatures', local_var_params['include_mate_features']))  # noqa: E501
        if 'include_non_solids' in local_var_params:
            query_params.append(('includeNonSolids', local_var_params['include_non_solids']))  # noqa: E501
        if 'include_mate_connectors' in local_var_params:
            query_params.append(('includeMateConnectors', local_var_params['include_mate_connectors']))  # noqa: E501
        if 'configuration' in local_var_params:
            query_params.append(('configuration', local_var_params['configuration']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/vnd.onshape.v1+json;charset=UTF-8; qs=0.1', 'application/json;charset=UTF-8; qs=0.9'])  # noqa: E501

        # Authentication setting
        auth_settings = ['OAuth2']  # noqa: E501

        return self.api_client.call_api(
            '/api/assemblies/d/{did}/{wvm}/{wvmid}/e/{eid}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_bill_of_materials1(self, did, wvm, wvmid, eid, **kwargs):  # noqa: E501
        """get_bill_of_materials1  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_bill_of_materials1(did, wvm, wvmid, eid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str did: (required)
        :param str wvm: (required)
        :param str wvmid: (required)
        :param str eid: (required)
        :param str metadata_workspace_id:
        :param list[str] bom_column_ids:
        :param bool indented:
        :param bool multi_level:
        :param bool generate_if_absent:
        :param str link_document_id:
        :param str configuration:
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_bill_of_materials1_with_http_info(did, wvm, wvmid, eid, **kwargs)  # noqa: E501
        else:
            (data) = self.get_bill_of_materials1_with_http_info(did, wvm, wvmid, eid, **kwargs)  # noqa: E501
            return data

    def get_bill_of_materials1_with_http_info(self, did, wvm, wvmid, eid, **kwargs):  # noqa: E501
        """get_bill_of_materials1  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_bill_of_materials1_with_http_info(did, wvm, wvmid, eid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str did: (required)
        :param str wvm: (required)
        :param str wvmid: (required)
        :param str eid: (required)
        :param str metadata_workspace_id:
        :param list[str] bom_column_ids:
        :param bool indented:
        :param bool multi_level:
        :param bool generate_if_absent:
        :param str link_document_id:
        :param str configuration:
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['did', 'wvm', 'wvmid', 'eid', 'metadata_workspace_id', 'bom_column_ids', 'indented', 'multi_level', 'generate_if_absent', 'link_document_id', 'configuration']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_bill_of_materials1" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'did' is set
        if ('did' not in local_var_params or
                local_var_params['did'] is None):
            raise ValueError("Missing the required parameter `did` when calling `get_bill_of_materials1`")  # noqa: E501
        # verify the required parameter 'wvm' is set
        if ('wvm' not in local_var_params or
                local_var_params['wvm'] is None):
            raise ValueError("Missing the required parameter `wvm` when calling `get_bill_of_materials1`")  # noqa: E501
        # verify the required parameter 'wvmid' is set
        if ('wvmid' not in local_var_params or
                local_var_params['wvmid'] is None):
            raise ValueError("Missing the required parameter `wvmid` when calling `get_bill_of_materials1`")  # noqa: E501
        # verify the required parameter 'eid' is set
        if ('eid' not in local_var_params or
                local_var_params['eid'] is None):
            raise ValueError("Missing the required parameter `eid` when calling `get_bill_of_materials1`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'did' in local_var_params:
            path_params['did'] = local_var_params['did']  # noqa: E501
        if 'wvm' in local_var_params:
            path_params['wvm'] = local_var_params['wvm']  # noqa: E501
        if 'wvmid' in local_var_params:
            path_params['wvmid'] = local_var_params['wvmid']  # noqa: E501
        if 'eid' in local_var_params:
            path_params['eid'] = local_var_params['eid']  # noqa: E501

        query_params = []
        if 'metadata_workspace_id' in local_var_params:
            query_params.append(('metadataWorkspaceId', local_var_params['metadata_workspace_id']))  # noqa: E501
        if 'bom_column_ids' in local_var_params:
            query_params.append(('bomColumnIds', local_var_params['bom_column_ids']))  # noqa: E501
            collection_formats['bomColumnIds'] = 'multi'  # noqa: E501
        if 'indented' in local_var_params:
            query_params.append(('indented', local_var_params['indented']))  # noqa: E501
        if 'multi_level' in local_var_params:
            query_params.append(('multiLevel', local_var_params['multi_level']))  # noqa: E501
        if 'generate_if_absent' in local_var_params:
            query_params.append(('generateIfAbsent', local_var_params['generate_if_absent']))  # noqa: E501
        if 'link_document_id' in local_var_params:
            query_params.append(('linkDocumentId', local_var_params['link_document_id']))  # noqa: E501
        if 'configuration' in local_var_params:
            query_params.append(('configuration', local_var_params['configuration']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/vnd.onshape.v1+json;charset=UTF-8; qs=0.1', 'application/json;charset=UTF-8; qs=0.9'])  # noqa: E501

        # Authentication setting
        auth_settings = ['OAuth2']  # noqa: E501

        return self.api_client.call_api(
            '/api/assemblies/d/{did}/{wvm}/{wvmid}/e/{eid}/bom', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_bounding_boxes(self, did, wvm, wvmid, eid, **kwargs):  # noqa: E501
        """get_bounding_boxes  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_bounding_boxes(did, wvm, wvmid, eid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str did: (required)
        :param str wvm: (required)
        :param str wvmid: (required)
        :param str eid: (required)
        :param str link_document_id:
        :param bool include_hidden:
        :param str display_state_id:
        :param str configuration:
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_bounding_boxes_with_http_info(did, wvm, wvmid, eid, **kwargs)  # noqa: E501
        else:
            (data) = self.get_bounding_boxes_with_http_info(did, wvm, wvmid, eid, **kwargs)  # noqa: E501
            return data

    def get_bounding_boxes_with_http_info(self, did, wvm, wvmid, eid, **kwargs):  # noqa: E501
        """get_bounding_boxes  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_bounding_boxes_with_http_info(did, wvm, wvmid, eid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str did: (required)
        :param str wvm: (required)
        :param str wvmid: (required)
        :param str eid: (required)
        :param str link_document_id:
        :param bool include_hidden:
        :param str display_state_id:
        :param str configuration:
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['did', 'wvm', 'wvmid', 'eid', 'link_document_id', 'include_hidden', 'display_state_id', 'configuration']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_bounding_boxes" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'did' is set
        if ('did' not in local_var_params or
                local_var_params['did'] is None):
            raise ValueError("Missing the required parameter `did` when calling `get_bounding_boxes`")  # noqa: E501
        # verify the required parameter 'wvm' is set
        if ('wvm' not in local_var_params or
                local_var_params['wvm'] is None):
            raise ValueError("Missing the required parameter `wvm` when calling `get_bounding_boxes`")  # noqa: E501
        # verify the required parameter 'wvmid' is set
        if ('wvmid' not in local_var_params or
                local_var_params['wvmid'] is None):
            raise ValueError("Missing the required parameter `wvmid` when calling `get_bounding_boxes`")  # noqa: E501
        # verify the required parameter 'eid' is set
        if ('eid' not in local_var_params or
                local_var_params['eid'] is None):
            raise ValueError("Missing the required parameter `eid` when calling `get_bounding_boxes`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'did' in local_var_params:
            path_params['did'] = local_var_params['did']  # noqa: E501
        if 'wvm' in local_var_params:
            path_params['wvm'] = local_var_params['wvm']  # noqa: E501
        if 'wvmid' in local_var_params:
            path_params['wvmid'] = local_var_params['wvmid']  # noqa: E501
        if 'eid' in local_var_params:
            path_params['eid'] = local_var_params['eid']  # noqa: E501

        query_params = []
        if 'link_document_id' in local_var_params:
            query_params.append(('linkDocumentId', local_var_params['link_document_id']))  # noqa: E501
        if 'include_hidden' in local_var_params:
            query_params.append(('includeHidden', local_var_params['include_hidden']))  # noqa: E501
        if 'display_state_id' in local_var_params:
            query_params.append(('displayStateId', local_var_params['display_state_id']))  # noqa: E501
        if 'configuration' in local_var_params:
            query_params.append(('configuration', local_var_params['configuration']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/vnd.onshape.v1+json;charset=UTF-8; qs=0.1', 'application/json;charset=UTF-8; qs=0.9'])  # noqa: E501

        # Authentication setting
        auth_settings = ['OAuth2']  # noqa: E501

        return self.api_client.call_api(
            '/api/assemblies/d/{did}/{wvm}/{wvmid}/e/{eid}/boundingboxes', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_feature_specs3(self, did, wvm, wvmid, eid, **kwargs):  # noqa: E501
        """get_feature_specs3  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_feature_specs3(did, wvm, wvmid, eid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str did: (required)
        :param str wvm: (required)
        :param str wvmid: (required)
        :param str eid: (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_feature_specs3_with_http_info(did, wvm, wvmid, eid, **kwargs)  # noqa: E501
        else:
            (data) = self.get_feature_specs3_with_http_info(did, wvm, wvmid, eid, **kwargs)  # noqa: E501
            return data

    def get_feature_specs3_with_http_info(self, did, wvm, wvmid, eid, **kwargs):  # noqa: E501
        """get_feature_specs3  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_feature_specs3_with_http_info(did, wvm, wvmid, eid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str did: (required)
        :param str wvm: (required)
        :param str wvmid: (required)
        :param str eid: (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['did', 'wvm', 'wvmid', 'eid']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_feature_specs3" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'did' is set
        if ('did' not in local_var_params or
                local_var_params['did'] is None):
            raise ValueError("Missing the required parameter `did` when calling `get_feature_specs3`")  # noqa: E501
        # verify the required parameter 'wvm' is set
        if ('wvm' not in local_var_params or
                local_var_params['wvm'] is None):
            raise ValueError("Missing the required parameter `wvm` when calling `get_feature_specs3`")  # noqa: E501
        # verify the required parameter 'wvmid' is set
        if ('wvmid' not in local_var_params or
                local_var_params['wvmid'] is None):
            raise ValueError("Missing the required parameter `wvmid` when calling `get_feature_specs3`")  # noqa: E501
        # verify the required parameter 'eid' is set
        if ('eid' not in local_var_params or
                local_var_params['eid'] is None):
            raise ValueError("Missing the required parameter `eid` when calling `get_feature_specs3`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'did' in local_var_params:
            path_params['did'] = local_var_params['did']  # noqa: E501
        if 'wvm' in local_var_params:
            path_params['wvm'] = local_var_params['wvm']  # noqa: E501
        if 'wvmid' in local_var_params:
            path_params['wvmid'] = local_var_params['wvmid']  # noqa: E501
        if 'eid' in local_var_params:
            path_params['eid'] = local_var_params['eid']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/vnd.onshape.v1+json;charset=UTF-8; qs=0.1', 'application/json;charset=UTF-8; qs=0.9'])  # noqa: E501

        # Authentication setting
        auth_settings = ['OAuth2']  # noqa: E501

        return self.api_client.call_api(
            '/api/assemblies/d/{did}/{wvm}/{wvmid}/e/{eid}/featurespecs', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_features2(self, did, wvm, wvmid, eid, **kwargs):  # noqa: E501
        """get_features2  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_features2(did, wvm, wvmid, eid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str did: (required)
        :param str wvm: (required)
        :param str wvmid: (required)
        :param str eid: (required)
        :param list[str] feature_id:
        :param str link_document_id:
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_features2_with_http_info(did, wvm, wvmid, eid, **kwargs)  # noqa: E501
        else:
            (data) = self.get_features2_with_http_info(did, wvm, wvmid, eid, **kwargs)  # noqa: E501
            return data

    def get_features2_with_http_info(self, did, wvm, wvmid, eid, **kwargs):  # noqa: E501
        """get_features2  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_features2_with_http_info(did, wvm, wvmid, eid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str did: (required)
        :param str wvm: (required)
        :param str wvmid: (required)
        :param str eid: (required)
        :param list[str] feature_id:
        :param str link_document_id:
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['did', 'wvm', 'wvmid', 'eid', 'feature_id', 'link_document_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_features2" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'did' is set
        if ('did' not in local_var_params or
                local_var_params['did'] is None):
            raise ValueError("Missing the required parameter `did` when calling `get_features2`")  # noqa: E501
        # verify the required parameter 'wvm' is set
        if ('wvm' not in local_var_params or
                local_var_params['wvm'] is None):
            raise ValueError("Missing the required parameter `wvm` when calling `get_features2`")  # noqa: E501
        # verify the required parameter 'wvmid' is set
        if ('wvmid' not in local_var_params or
                local_var_params['wvmid'] is None):
            raise ValueError("Missing the required parameter `wvmid` when calling `get_features2`")  # noqa: E501
        # verify the required parameter 'eid' is set
        if ('eid' not in local_var_params or
                local_var_params['eid'] is None):
            raise ValueError("Missing the required parameter `eid` when calling `get_features2`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'did' in local_var_params:
            path_params['did'] = local_var_params['did']  # noqa: E501
        if 'wvm' in local_var_params:
            path_params['wvm'] = local_var_params['wvm']  # noqa: E501
        if 'wvmid' in local_var_params:
            path_params['wvmid'] = local_var_params['wvmid']  # noqa: E501
        if 'eid' in local_var_params:
            path_params['eid'] = local_var_params['eid']  # noqa: E501

        query_params = []
        if 'feature_id' in local_var_params:
            query_params.append(('featureId', local_var_params['feature_id']))  # noqa: E501
            collection_formats['featureId'] = 'multi'  # noqa: E501
        if 'link_document_id' in local_var_params:
            query_params.append(('linkDocumentId', local_var_params['link_document_id']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/vnd.onshape.v1+json;charset=UTF-8; qs=0.1', 'application/json;charset=UTF-8; qs=0.9'])  # noqa: E501

        # Authentication setting
        auth_settings = ['OAuth2']  # noqa: E501

        return self.api_client.call_api(
            '/api/assemblies/d/{did}/{wvm}/{wvmid}/e/{eid}/features', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_named_views1(self, did, eid, **kwargs):  # noqa: E501
        """get_named_views1  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_named_views1(did, eid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str did: (required)
        :param str eid: (required)
        :param bool skip_perspective:
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_named_views1_with_http_info(did, eid, **kwargs)  # noqa: E501
        else:
            (data) = self.get_named_views1_with_http_info(did, eid, **kwargs)  # noqa: E501
            return data

    def get_named_views1_with_http_info(self, did, eid, **kwargs):  # noqa: E501
        """get_named_views1  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_named_views1_with_http_info(did, eid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str did: (required)
        :param str eid: (required)
        :param bool skip_perspective:
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['did', 'eid', 'skip_perspective']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_named_views1" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'did' is set
        if ('did' not in local_var_params or
                local_var_params['did'] is None):
            raise ValueError("Missing the required parameter `did` when calling `get_named_views1`")  # noqa: E501
        # verify the required parameter 'eid' is set
        if ('eid' not in local_var_params or
                local_var_params['eid'] is None):
            raise ValueError("Missing the required parameter `eid` when calling `get_named_views1`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'did' in local_var_params:
            path_params['did'] = local_var_params['did']  # noqa: E501
        if 'eid' in local_var_params:
            path_params['eid'] = local_var_params['eid']  # noqa: E501

        query_params = []
        if 'skip_perspective' in local_var_params:
            query_params.append(('skipPerspective', local_var_params['skip_perspective']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/vnd.onshape.v1+json;charset=UTF-8; qs=0.1', 'application/json;charset=UTF-8; qs=0.9'])  # noqa: E501

        # Authentication setting
        auth_settings = ['OAuth2']  # noqa: E501

        return self.api_client.call_api(
            '/api/assemblies/d/{did}/e/{eid}/namedViews', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_or_create_bill_of_materials_element(self, did, wid, eid, **kwargs):  # noqa: E501
        """get_or_create_bill_of_materials_element  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_or_create_bill_of_materials_element(did, wid, eid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str did: (required)
        :param str wid: (required)
        :param str eid: (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_or_create_bill_of_materials_element_with_http_info(did, wid, eid, **kwargs)  # noqa: E501
        else:
            (data) = self.get_or_create_bill_of_materials_element_with_http_info(did, wid, eid, **kwargs)  # noqa: E501
            return data

    def get_or_create_bill_of_materials_element_with_http_info(self, did, wid, eid, **kwargs):  # noqa: E501
        """get_or_create_bill_of_materials_element  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_or_create_bill_of_materials_element_with_http_info(did, wid, eid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str did: (required)
        :param str wid: (required)
        :param str eid: (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['did', 'wid', 'eid']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_or_create_bill_of_materials_element" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'did' is set
        if ('did' not in local_var_params or
                local_var_params['did'] is None):
            raise ValueError("Missing the required parameter `did` when calling `get_or_create_bill_of_materials_element`")  # noqa: E501
        # verify the required parameter 'wid' is set
        if ('wid' not in local_var_params or
                local_var_params['wid'] is None):
            raise ValueError("Missing the required parameter `wid` when calling `get_or_create_bill_of_materials_element`")  # noqa: E501
        # verify the required parameter 'eid' is set
        if ('eid' not in local_var_params or
                local_var_params['eid'] is None):
            raise ValueError("Missing the required parameter `eid` when calling `get_or_create_bill_of_materials_element`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'did' in local_var_params:
            path_params['did'] = local_var_params['did']  # noqa: E501
        if 'wid' in local_var_params:
            path_params['wid'] = local_var_params['wid']  # noqa: E501
        if 'eid' in local_var_params:
            path_params['eid'] = local_var_params['eid']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/vnd.onshape.v1+json;charset=UTF-8; qs=0.1', 'application/json;charset=UTF-8; qs=0.9'])  # noqa: E501

        # Authentication setting
        auth_settings = ['OAuth2']  # noqa: E501

        return self.api_client.call_api(
            '/api/assemblies/d/{did}/w/{wid}/e/{eid}/bomelement', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_shaded_views3(self, did, wvm, wvmid, eid, **kwargs):  # noqa: E501
        """get_shaded_views3  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_shaded_views3(did, wvm, wvmid, eid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str did: (required)
        :param str wvm: (required)
        :param str wvmid: (required)
        :param str eid: (required)
        :param str link_document_id:
        :param str view_matrix:
        :param int output_height:
        :param int output_width:
        :param float pixel_size:
        :param str edges:
        :param bool show_all_parts:
        :param bool include_surfaces:
        :param bool use_anti_aliasing:
        :param str display_state_id:
        :param str configuration:
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_shaded_views3_with_http_info(did, wvm, wvmid, eid, **kwargs)  # noqa: E501
        else:
            (data) = self.get_shaded_views3_with_http_info(did, wvm, wvmid, eid, **kwargs)  # noqa: E501
            return data

    def get_shaded_views3_with_http_info(self, did, wvm, wvmid, eid, **kwargs):  # noqa: E501
        """get_shaded_views3  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_shaded_views3_with_http_info(did, wvm, wvmid, eid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str did: (required)
        :param str wvm: (required)
        :param str wvmid: (required)
        :param str eid: (required)
        :param str link_document_id:
        :param str view_matrix:
        :param int output_height:
        :param int output_width:
        :param float pixel_size:
        :param str edges:
        :param bool show_all_parts:
        :param bool include_surfaces:
        :param bool use_anti_aliasing:
        :param str display_state_id:
        :param str configuration:
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['did', 'wvm', 'wvmid', 'eid', 'link_document_id', 'view_matrix', 'output_height', 'output_width', 'pixel_size', 'edges', 'show_all_parts', 'include_surfaces', 'use_anti_aliasing', 'display_state_id', 'configuration']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_shaded_views3" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'did' is set
        if ('did' not in local_var_params or
                local_var_params['did'] is None):
            raise ValueError("Missing the required parameter `did` when calling `get_shaded_views3`")  # noqa: E501
        # verify the required parameter 'wvm' is set
        if ('wvm' not in local_var_params or
                local_var_params['wvm'] is None):
            raise ValueError("Missing the required parameter `wvm` when calling `get_shaded_views3`")  # noqa: E501
        # verify the required parameter 'wvmid' is set
        if ('wvmid' not in local_var_params or
                local_var_params['wvmid'] is None):
            raise ValueError("Missing the required parameter `wvmid` when calling `get_shaded_views3`")  # noqa: E501
        # verify the required parameter 'eid' is set
        if ('eid' not in local_var_params or
                local_var_params['eid'] is None):
            raise ValueError("Missing the required parameter `eid` when calling `get_shaded_views3`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'did' in local_var_params:
            path_params['did'] = local_var_params['did']  # noqa: E501
        if 'wvm' in local_var_params:
            path_params['wvm'] = local_var_params['wvm']  # noqa: E501
        if 'wvmid' in local_var_params:
            path_params['wvmid'] = local_var_params['wvmid']  # noqa: E501
        if 'eid' in local_var_params:
            path_params['eid'] = local_var_params['eid']  # noqa: E501

        query_params = []
        if 'link_document_id' in local_var_params:
            query_params.append(('linkDocumentId', local_var_params['link_document_id']))  # noqa: E501
        if 'view_matrix' in local_var_params:
            query_params.append(('viewMatrix', local_var_params['view_matrix']))  # noqa: E501
        if 'output_height' in local_var_params:
            query_params.append(('outputHeight', local_var_params['output_height']))  # noqa: E501
        if 'output_width' in local_var_params:
            query_params.append(('outputWidth', local_var_params['output_width']))  # noqa: E501
        if 'pixel_size' in local_var_params:
            query_params.append(('pixelSize', local_var_params['pixel_size']))  # noqa: E501
        if 'edges' in local_var_params:
            query_params.append(('edges', local_var_params['edges']))  # noqa: E501
        if 'show_all_parts' in local_var_params:
            query_params.append(('showAllParts', local_var_params['show_all_parts']))  # noqa: E501
        if 'include_surfaces' in local_var_params:
            query_params.append(('includeSurfaces', local_var_params['include_surfaces']))  # noqa: E501
        if 'use_anti_aliasing' in local_var_params:
            query_params.append(('useAntiAliasing', local_var_params['use_anti_aliasing']))  # noqa: E501
        if 'display_state_id' in local_var_params:
            query_params.append(('displayStateId', local_var_params['display_state_id']))  # noqa: E501
        if 'configuration' in local_var_params:
            query_params.append(('configuration', local_var_params['configuration']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/vnd.onshape.v1+json;charset=UTF-8; qs=0.1', 'application/json;charset=UTF-8; qs=0.9'])  # noqa: E501

        # Authentication setting
        auth_settings = ['OAuth2']  # noqa: E501

        return self.api_client.call_api(
            '/api/assemblies/d/{did}/{wvm}/{wvmid}/e/{eid}/shadedviews', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_translator_formats(self, did, wid, eid, **kwargs):  # noqa: E501
        """get_translator_formats  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_translator_formats(did, wid, eid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str did: (required)
        :param str wid: (required)
        :param str eid: (required)
        :param bool check_content:
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_translator_formats_with_http_info(did, wid, eid, **kwargs)  # noqa: E501
        else:
            (data) = self.get_translator_formats_with_http_info(did, wid, eid, **kwargs)  # noqa: E501
            return data

    def get_translator_formats_with_http_info(self, did, wid, eid, **kwargs):  # noqa: E501
        """get_translator_formats  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_translator_formats_with_http_info(did, wid, eid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str did: (required)
        :param str wid: (required)
        :param str eid: (required)
        :param bool check_content:
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['did', 'wid', 'eid', 'check_content']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_translator_formats" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'did' is set
        if ('did' not in local_var_params or
                local_var_params['did'] is None):
            raise ValueError("Missing the required parameter `did` when calling `get_translator_formats`")  # noqa: E501
        # verify the required parameter 'wid' is set
        if ('wid' not in local_var_params or
                local_var_params['wid'] is None):
            raise ValueError("Missing the required parameter `wid` when calling `get_translator_formats`")  # noqa: E501
        # verify the required parameter 'eid' is set
        if ('eid' not in local_var_params or
                local_var_params['eid'] is None):
            raise ValueError("Missing the required parameter `eid` when calling `get_translator_formats`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'did' in local_var_params:
            path_params['did'] = local_var_params['did']  # noqa: E501
        if 'wid' in local_var_params:
            path_params['wid'] = local_var_params['wid']  # noqa: E501
        if 'eid' in local_var_params:
            path_params['eid'] = local_var_params['eid']  # noqa: E501

        query_params = []
        if 'check_content' in local_var_params:
            query_params.append(('checkContent', local_var_params['check_content']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/vnd.onshape.v1+json;charset=UTF-8; qs=0.1', 'application/json;charset=UTF-8; qs=0.9'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/assemblies/d/{did}/w/{wid}/e/{eid}/translationformats', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def insert_transformed_instances(self, did, eid, wid, bt_assembly_transformed_instances_definition_params, **kwargs):  # noqa: E501
        """insert_transformed_instances  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.insert_transformed_instances(did, eid, wid, bt_assembly_transformed_instances_definition_params, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str did: (required)
        :param str eid: (required)
        :param str wid: (required)
        :param BTAssemblyTransformedInstancesDefinitionParams bt_assembly_transformed_instances_definition_params: (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.insert_transformed_instances_with_http_info(did, eid, wid, bt_assembly_transformed_instances_definition_params, **kwargs)  # noqa: E501
        else:
            (data) = self.insert_transformed_instances_with_http_info(did, eid, wid, bt_assembly_transformed_instances_definition_params, **kwargs)  # noqa: E501
            return data

    def insert_transformed_instances_with_http_info(self, did, eid, wid, bt_assembly_transformed_instances_definition_params, **kwargs):  # noqa: E501
        """insert_transformed_instances  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.insert_transformed_instances_with_http_info(did, eid, wid, bt_assembly_transformed_instances_definition_params, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str did: (required)
        :param str eid: (required)
        :param str wid: (required)
        :param BTAssemblyTransformedInstancesDefinitionParams bt_assembly_transformed_instances_definition_params: (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['did', 'eid', 'wid', 'bt_assembly_transformed_instances_definition_params']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method insert_transformed_instances" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'did' is set
        if ('did' not in local_var_params or
                local_var_params['did'] is None):
            raise ValueError("Missing the required parameter `did` when calling `insert_transformed_instances`")  # noqa: E501
        # verify the required parameter 'eid' is set
        if ('eid' not in local_var_params or
                local_var_params['eid'] is None):
            raise ValueError("Missing the required parameter `eid` when calling `insert_transformed_instances`")  # noqa: E501
        # verify the required parameter 'wid' is set
        if ('wid' not in local_var_params or
                local_var_params['wid'] is None):
            raise ValueError("Missing the required parameter `wid` when calling `insert_transformed_instances`")  # noqa: E501
        # verify the required parameter 'bt_assembly_transformed_instances_definition_params' is set
        if ('bt_assembly_transformed_instances_definition_params' not in local_var_params or
                local_var_params['bt_assembly_transformed_instances_definition_params'] is None):
            raise ValueError("Missing the required parameter `bt_assembly_transformed_instances_definition_params` when calling `insert_transformed_instances`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'did' in local_var_params:
            path_params['did'] = local_var_params['did']  # noqa: E501
        if 'eid' in local_var_params:
            path_params['eid'] = local_var_params['eid']  # noqa: E501
        if 'wid' in local_var_params:
            path_params['wid'] = local_var_params['wid']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'bt_assembly_transformed_instances_definition_params' in local_var_params:
            body_params = local_var_params['bt_assembly_transformed_instances_definition_params']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/vnd.onshape.v1+json;charset=UTF-8; qs=0.1', 'application/json;charset=UTF-8; qs=0.9'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json;charset=UTF-8'])  # noqa: E501

        # Authentication setting
        auth_settings = ['OAuth2']  # noqa: E501

        return self.api_client.call_api(
            '/api/assemblies/d/{did}/w/{wid}/e/{eid}/transformedinstances', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def transform_occurrences(self, did, eid, wid, bt_assembly_transform_definition_params, **kwargs):  # noqa: E501
        """transform_occurrences  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.transform_occurrences(did, eid, wid, bt_assembly_transform_definition_params, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str did: (required)
        :param str eid: (required)
        :param str wid: (required)
        :param BTAssemblyTransformDefinitionParams bt_assembly_transform_definition_params: (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.transform_occurrences_with_http_info(did, eid, wid, bt_assembly_transform_definition_params, **kwargs)  # noqa: E501
        else:
            (data) = self.transform_occurrences_with_http_info(did, eid, wid, bt_assembly_transform_definition_params, **kwargs)  # noqa: E501
            return data

    def transform_occurrences_with_http_info(self, did, eid, wid, bt_assembly_transform_definition_params, **kwargs):  # noqa: E501
        """transform_occurrences  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.transform_occurrences_with_http_info(did, eid, wid, bt_assembly_transform_definition_params, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str did: (required)
        :param str eid: (required)
        :param str wid: (required)
        :param BTAssemblyTransformDefinitionParams bt_assembly_transform_definition_params: (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['did', 'eid', 'wid', 'bt_assembly_transform_definition_params']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method transform_occurrences" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'did' is set
        if ('did' not in local_var_params or
                local_var_params['did'] is None):
            raise ValueError("Missing the required parameter `did` when calling `transform_occurrences`")  # noqa: E501
        # verify the required parameter 'eid' is set
        if ('eid' not in local_var_params or
                local_var_params['eid'] is None):
            raise ValueError("Missing the required parameter `eid` when calling `transform_occurrences`")  # noqa: E501
        # verify the required parameter 'wid' is set
        if ('wid' not in local_var_params or
                local_var_params['wid'] is None):
            raise ValueError("Missing the required parameter `wid` when calling `transform_occurrences`")  # noqa: E501
        # verify the required parameter 'bt_assembly_transform_definition_params' is set
        if ('bt_assembly_transform_definition_params' not in local_var_params or
                local_var_params['bt_assembly_transform_definition_params'] is None):
            raise ValueError("Missing the required parameter `bt_assembly_transform_definition_params` when calling `transform_occurrences`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'did' in local_var_params:
            path_params['did'] = local_var_params['did']  # noqa: E501
        if 'eid' in local_var_params:
            path_params['eid'] = local_var_params['eid']  # noqa: E501
        if 'wid' in local_var_params:
            path_params['wid'] = local_var_params['wid']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'bt_assembly_transform_definition_params' in local_var_params:
            body_params = local_var_params['bt_assembly_transform_definition_params']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/vnd.onshape.v1+json;charset=UTF-8; qs=0.1', 'application/json;charset=UTF-8; qs=0.9'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json;charset=UTF-8'])  # noqa: E501

        # Authentication setting
        auth_settings = ['OAuth2']  # noqa: E501

        return self.api_client.call_api(
            '/api/assemblies/d/{did}/w/{wid}/e/{eid}/occurrencetransforms', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def translate_format(self, did, wv, wvid, eid, bt_translate_format_params, **kwargs):  # noqa: E501
        """translate_format  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.translate_format(did, wv, wvid, eid, bt_translate_format_params, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str did: (required)
        :param str wv: (required)
        :param str wvid: (required)
        :param str eid: (required)
        :param BTTranslateFormatParams bt_translate_format_params: (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.translate_format_with_http_info(did, wv, wvid, eid, bt_translate_format_params, **kwargs)  # noqa: E501
        else:
            (data) = self.translate_format_with_http_info(did, wv, wvid, eid, bt_translate_format_params, **kwargs)  # noqa: E501
            return data

    def translate_format_with_http_info(self, did, wv, wvid, eid, bt_translate_format_params, **kwargs):  # noqa: E501
        """translate_format  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.translate_format_with_http_info(did, wv, wvid, eid, bt_translate_format_params, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str did: (required)
        :param str wv: (required)
        :param str wvid: (required)
        :param str eid: (required)
        :param BTTranslateFormatParams bt_translate_format_params: (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['did', 'wv', 'wvid', 'eid', 'bt_translate_format_params']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method translate_format" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'did' is set
        if ('did' not in local_var_params or
                local_var_params['did'] is None):
            raise ValueError("Missing the required parameter `did` when calling `translate_format`")  # noqa: E501
        # verify the required parameter 'wv' is set
        if ('wv' not in local_var_params or
                local_var_params['wv'] is None):
            raise ValueError("Missing the required parameter `wv` when calling `translate_format`")  # noqa: E501
        # verify the required parameter 'wvid' is set
        if ('wvid' not in local_var_params or
                local_var_params['wvid'] is None):
            raise ValueError("Missing the required parameter `wvid` when calling `translate_format`")  # noqa: E501
        # verify the required parameter 'eid' is set
        if ('eid' not in local_var_params or
                local_var_params['eid'] is None):
            raise ValueError("Missing the required parameter `eid` when calling `translate_format`")  # noqa: E501
        # verify the required parameter 'bt_translate_format_params' is set
        if ('bt_translate_format_params' not in local_var_params or
                local_var_params['bt_translate_format_params'] is None):
            raise ValueError("Missing the required parameter `bt_translate_format_params` when calling `translate_format`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'did' in local_var_params:
            path_params['did'] = local_var_params['did']  # noqa: E501
        if 'wv' in local_var_params:
            path_params['wv'] = local_var_params['wv']  # noqa: E501
        if 'wvid' in local_var_params:
            path_params['wvid'] = local_var_params['wvid']  # noqa: E501
        if 'eid' in local_var_params:
            path_params['eid'] = local_var_params['eid']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'bt_translate_format_params' in local_var_params:
            body_params = local_var_params['bt_translate_format_params']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/vnd.onshape.v1+json;charset=UTF-8; qs=0.1', 'application/json;charset=UTF-8; qs=0.9'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json;charset=UTF-8'])  # noqa: E501

        # Authentication setting
        auth_settings = ['OAuth2']  # noqa: E501

        return self.api_client.call_api(
            '/api/assemblies/d/{did}/{wv}/{wvid}/e/{eid}/translations', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def update_feature2(self, did, wid, eid, fid, **kwargs):  # noqa: E501
        """update_feature2  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_feature2(did, wid, eid, fid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str did: (required)
        :param str wid: (required)
        :param str eid: (required)
        :param str fid: (required)
        :param str body:
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.update_feature2_with_http_info(did, wid, eid, fid, **kwargs)  # noqa: E501
        else:
            (data) = self.update_feature2_with_http_info(did, wid, eid, fid, **kwargs)  # noqa: E501
            return data

    def update_feature2_with_http_info(self, did, wid, eid, fid, **kwargs):  # noqa: E501
        """update_feature2  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_feature2_with_http_info(did, wid, eid, fid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str did: (required)
        :param str wid: (required)
        :param str eid: (required)
        :param str fid: (required)
        :param str body:
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['did', 'wid', 'eid', 'fid', 'body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method update_feature2" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'did' is set
        if ('did' not in local_var_params or
                local_var_params['did'] is None):
            raise ValueError("Missing the required parameter `did` when calling `update_feature2`")  # noqa: E501
        # verify the required parameter 'wid' is set
        if ('wid' not in local_var_params or
                local_var_params['wid'] is None):
            raise ValueError("Missing the required parameter `wid` when calling `update_feature2`")  # noqa: E501
        # verify the required parameter 'eid' is set
        if ('eid' not in local_var_params or
                local_var_params['eid'] is None):
            raise ValueError("Missing the required parameter `eid` when calling `update_feature2`")  # noqa: E501
        # verify the required parameter 'fid' is set
        if ('fid' not in local_var_params or
                local_var_params['fid'] is None):
            raise ValueError("Missing the required parameter `fid` when calling `update_feature2`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'did' in local_var_params:
            path_params['did'] = local_var_params['did']  # noqa: E501
        if 'wid' in local_var_params:
            path_params['wid'] = local_var_params['wid']  # noqa: E501
        if 'eid' in local_var_params:
            path_params['eid'] = local_var_params['eid']  # noqa: E501
        if 'fid' in local_var_params:
            path_params['fid'] = local_var_params['fid']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in local_var_params:
            body_params = local_var_params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/vnd.onshape.v1+json;charset=UTF-8; qs=0.1', 'application/json;charset=UTF-8; qs=0.9'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json;charset=UTF-8'])  # noqa: E501

        # Authentication setting
        auth_settings = ['OAuth2']  # noqa: E501

        return self.api_client.call_api(
            '/api/assemblies/d/{did}/w/{wid}/e/{eid}/features/featureid/{fid}', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    Onshape REST API

    The Onshape REST API consumed by all clients.  # noqa: E501

    OpenAPI spec version: 1.96
    Contact: api-support@onshape.zendesk.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six


class Link(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'operation_ref': 'str',
        'operation_id': 'str',
        'parameters': 'dict(str, str)',
        'request_body': 'object',
        'headers': 'dict(str, Header)',
        'description': 'str',
        'getref': 'str',
        'extensions': 'dict(str, object)',
        'server': 'Server'
    }

    attribute_map = {
        'operation_ref': 'operationRef',
        'operation_id': 'operationId',
        'parameters': 'parameters',
        'request_body': 'requestBody',
        'headers': 'headers',
        'description': 'description',
        'getref': 'get$ref',
        'extensions': 'extensions',
        'server': 'server'
    }

    def __init__(self, operation_ref=None, operation_id=None, parameters=None, request_body=None, headers=None, description=None, getref=None, extensions=None, server=None):  # noqa: E501
        """Link - a model defined in OpenAPI"""  # noqa: E501

        self._operation_ref = None
        self._operation_id = None
        self._parameters = None
        self._request_body = None
        self._headers = None
        self._description = None
        self._getref = None
        self._extensions = None
        self._server = None
        self.discriminator = None

        if operation_ref is not None:
            self.operation_ref = operation_ref
        if operation_id is not None:
            self.operation_id = operation_id
        if parameters is not None:
            self.parameters = parameters
        if request_body is not None:
            self.request_body = request_body
        if headers is not None:
            self.headers = headers
        if description is not None:
            self.description = description
        if getref is not None:
            self.getref = getref
        if extensions is not None:
            self.extensions = extensions
        if server is not None:
            self.server = server

    @property
    def operation_ref(self):
        """Gets the operation_ref of this Link.  # noqa: E501


        :return: The operation_ref of this Link.  # noqa: E501
        :rtype: str
        """
        return self._operation_ref

    @operation_ref.setter
    def operation_ref(self, operation_ref):
        """Sets the operation_ref of this Link.


        :param operation_ref: The operation_ref of this Link.  # noqa: E501
        :type: str
        """

        self._operation_ref = operation_ref

    @property
    def operation_id(self):
        """Gets the operation_id of this Link.  # noqa: E501


        :return: The operation_id of this Link.  # noqa: E501
        :rtype: str
        """
        return self._operation_id

    @operation_id.setter
    def operation_id(self, operation_id):
        """Sets the operation_id of this Link.


        :param operation_id: The operation_id of this Link.  # noqa: E501
        :type: str
        """

        self._operation_id = operation_id

    @property
    def parameters(self):
        """Gets the parameters of this Link.  # noqa: E501


        :return: The parameters of this Link.  # noqa: E501
        :rtype: dict(str, str)
        """
        return self._parameters

    @parameters.setter
    def parameters(self, parameters):
        """Sets the parameters of this Link.


        :param parameters: The parameters of this Link.  # noqa: E501
        :type: dict(str, str)
        """

        self._parameters = parameters

    @property
    def request_body(self):
        """Gets the request_body of this Link.  # noqa: E501


        :return: The request_body of this Link.  # noqa: E501
        :rtype: object
        """
        return self._request_body

    @request_body.setter
    def request_body(self, request_body):
        """Sets the request_body of this Link.


        :param request_body: The request_body of this Link.  # noqa: E501
        :type: object
        """

        self._request_body = request_body

    @property
    def headers(self):
        """Gets the headers of this Link.  # noqa: E501


        :return: The headers of this Link.  # noqa: E501
        :rtype: dict(str, Header)
        """
        return self._headers

    @headers.setter
    def headers(self, headers):
        """Sets the headers of this Link.


        :param headers: The headers of this Link.  # noqa: E501
        :type: dict(str, Header)
        """

        self._headers = headers

    @property
    def description(self):
        """Gets the description of this Link.  # noqa: E501


        :return: The description of this Link.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this Link.


        :param description: The description of this Link.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def getref(self):
        """Gets the getref of this Link.  # noqa: E501


        :return: The getref of this Link.  # noqa: E501
        :rtype: str
        """
        return self._getref

    @getref.setter
    def getref(self, getref):
        """Sets the getref of this Link.


        :param getref: The getref of this Link.  # noqa: E501
        :type: str
        """

        self._getref = getref

    @property
    def extensions(self):
        """Gets the extensions of this Link.  # noqa: E501


        :return: The extensions of this Link.  # noqa: E501
        :rtype: dict(str, object)
        """
        return self._extensions

    @extensions.setter
    def extensions(self, extensions):
        """Sets the extensions of this Link.


        :param extensions: The extensions of this Link.  # noqa: E501
        :type: dict(str, object)
        """

        self._extensions = extensions

    @property
    def server(self):
        """Gets the server of this Link.  # noqa: E501


        :return: The server of this Link.  # noqa: E501
        :rtype: Server
        """
        return self._server

    @server.setter
    def server(self, server):
        """Sets the server of this Link.


        :param server: The server of this Link.  # noqa: E501
        :type: Server
        """

        self._server = server

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Link):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Onshape REST API

    The Onshape REST API consumed by all clients.  # noqa: E501

    OpenAPI spec version: 1.96
    Contact: api-support@onshape.zendesk.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six


class BTWebRendererPerformanceMeasurementParams(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'vendor': 'str',
        'renderer': 'str',
        'triangles_per_second': 'float',
        'lines_per_second': 'float'
    }

    attribute_map = {
        'vendor': 'vendor',
        'renderer': 'renderer',
        'triangles_per_second': 'trianglesPerSecond',
        'lines_per_second': 'linesPerSecond'
    }

    def __init__(self, vendor=None, renderer=None, triangles_per_second=None, lines_per_second=None):  # noqa: E501
        """BTWebRendererPerformanceMeasurementParams - a model defined in OpenAPI"""  # noqa: E501

        self._vendor = None
        self._renderer = None
        self._triangles_per_second = None
        self._lines_per_second = None
        self.discriminator = None

        if vendor is not None:
            self.vendor = vendor
        if renderer is not None:
            self.renderer = renderer
        if triangles_per_second is not None:
            self.triangles_per_second = triangles_per_second
        if lines_per_second is not None:
            self.lines_per_second = lines_per_second

    @property
    def vendor(self):
        """Gets the vendor of this BTWebRendererPerformanceMeasurementParams.  # noqa: E501


        :return: The vendor of this BTWebRendererPerformanceMeasurementParams.  # noqa: E501
        :rtype: str
        """
        return self._vendor

    @vendor.setter
    def vendor(self, vendor):
        """Sets the vendor of this BTWebRendererPerformanceMeasurementParams.


        :param vendor: The vendor of this BTWebRendererPerformanceMeasurementParams.  # noqa: E501
        :type: str
        """

        self._vendor = vendor

    @property
    def renderer(self):
        """Gets the renderer of this BTWebRendererPerformanceMeasurementParams.  # noqa: E501


        :return: The renderer of this BTWebRendererPerformanceMeasurementParams.  # noqa: E501
        :rtype: str
        """
        return self._renderer

    @renderer.setter
    def renderer(self, renderer):
        """Sets the renderer of this BTWebRendererPerformanceMeasurementParams.


        :param renderer: The renderer of this BTWebRendererPerformanceMeasurementParams.  # noqa: E501
        :type: str
        """

        self._renderer = renderer

    @property
    def triangles_per_second(self):
        """Gets the triangles_per_second of this BTWebRendererPerformanceMeasurementParams.  # noqa: E501


        :return: The triangles_per_second of this BTWebRendererPerformanceMeasurementParams.  # noqa: E501
        :rtype: float
        """
        return self._triangles_per_second

    @triangles_per_second.setter
    def triangles_per_second(self, triangles_per_second):
        """Sets the triangles_per_second of this BTWebRendererPerformanceMeasurementParams.


        :param triangles_per_second: The triangles_per_second of this BTWebRendererPerformanceMeasurementParams.  # noqa: E501
        :type: float
        """

        self._triangles_per_second = triangles_per_second

    @property
    def lines_per_second(self):
        """Gets the lines_per_second of this BTWebRendererPerformanceMeasurementParams.  # noqa: E501


        :return: The lines_per_second of this BTWebRendererPerformanceMeasurementParams.  # noqa: E501
        :rtype: float
        """
        return self._lines_per_second

    @lines_per_second.setter
    def lines_per_second(self, lines_per_second):
        """Sets the lines_per_second of this BTWebRendererPerformanceMeasurementParams.


        :param lines_per_second: The lines_per_second of this BTWebRendererPerformanceMeasurementParams.  # noqa: E501
        :type: float
        """

        self._lines_per_second = lines_per_second

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BTWebRendererPerformanceMeasurementParams):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Onshape REST API

    The Onshape REST API consumed by all clients.  # noqa: E501

    OpenAPI spec version: 1.96
    Contact: api-support@onshape.zendesk.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six


class BTDocumentOptionsParams(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'cpp_server_limit': 'int',
        'thumbnail_cpp_server_limit': 'int',
        'linked_cpp_server_limit': 'int',
        'drawing_server_memory': 'int',
        'cpp_server_default_element_limit': 'int',
        'cpp_server_memory': 'int',
        'enable_cpp_server_memory_diagnostics': 'bool',
        'extended_display_check': 'bool',
        'skip_retrieval_test': 'bool',
        'document_memory': 'int'
    }

    attribute_map = {
        'cpp_server_limit': 'cppServerLimit',
        'thumbnail_cpp_server_limit': 'thumbnailCppServerLimit',
        'linked_cpp_server_limit': 'linkedCppServerLimit',
        'drawing_server_memory': 'drawingServerMemory',
        'cpp_server_default_element_limit': 'cppServerDefaultElementLimit',
        'cpp_server_memory': 'cppServerMemory',
        'enable_cpp_server_memory_diagnostics': 'enableCppServerMemoryDiagnostics',
        'extended_display_check': 'extendedDisplayCheck',
        'skip_retrieval_test': 'skipRetrievalTest',
        'document_memory': 'documentMemory'
    }

    def __init__(self, cpp_server_limit=None, thumbnail_cpp_server_limit=None, linked_cpp_server_limit=None, drawing_server_memory=None, cpp_server_default_element_limit=None, cpp_server_memory=None, enable_cpp_server_memory_diagnostics=None, extended_display_check=None, skip_retrieval_test=None, document_memory=None):  # noqa: E501
        """BTDocumentOptionsParams - a model defined in OpenAPI"""  # noqa: E501

        self._cpp_server_limit = None
        self._thumbnail_cpp_server_limit = None
        self._linked_cpp_server_limit = None
        self._drawing_server_memory = None
        self._cpp_server_default_element_limit = None
        self._cpp_server_memory = None
        self._enable_cpp_server_memory_diagnostics = None
        self._extended_display_check = None
        self._skip_retrieval_test = None
        self._document_memory = None
        self.discriminator = None

        if cpp_server_limit is not None:
            self.cpp_server_limit = cpp_server_limit
        if thumbnail_cpp_server_limit is not None:
            self.thumbnail_cpp_server_limit = thumbnail_cpp_server_limit
        if linked_cpp_server_limit is not None:
            self.linked_cpp_server_limit = linked_cpp_server_limit
        if drawing_server_memory is not None:
            self.drawing_server_memory = drawing_server_memory
        if cpp_server_default_element_limit is not None:
            self.cpp_server_default_element_limit = cpp_server_default_element_limit
        if cpp_server_memory is not None:
            self.cpp_server_memory = cpp_server_memory
        if enable_cpp_server_memory_diagnostics is not None:
            self.enable_cpp_server_memory_diagnostics = enable_cpp_server_memory_diagnostics
        if extended_display_check is not None:
            self.extended_display_check = extended_display_check
        if skip_retrieval_test is not None:
            self.skip_retrieval_test = skip_retrieval_test
        if document_memory is not None:
            self.document_memory = document_memory

    @property
    def cpp_server_limit(self):
        """Gets the cpp_server_limit of this BTDocumentOptionsParams.  # noqa: E501


        :return: The cpp_server_limit of this BTDocumentOptionsParams.  # noqa: E501
        :rtype: int
        """
        return self._cpp_server_limit

    @cpp_server_limit.setter
    def cpp_server_limit(self, cpp_server_limit):
        """Sets the cpp_server_limit of this BTDocumentOptionsParams.


        :param cpp_server_limit: The cpp_server_limit of this BTDocumentOptionsParams.  # noqa: E501
        :type: int
        """

        self._cpp_server_limit = cpp_server_limit

    @property
    def thumbnail_cpp_server_limit(self):
        """Gets the thumbnail_cpp_server_limit of this BTDocumentOptionsParams.  # noqa: E501


        :return: The thumbnail_cpp_server_limit of this BTDocumentOptionsParams.  # noqa: E501
        :rtype: int
        """
        return self._thumbnail_cpp_server_limit

    @thumbnail_cpp_server_limit.setter
    def thumbnail_cpp_server_limit(self, thumbnail_cpp_server_limit):
        """Sets the thumbnail_cpp_server_limit of this BTDocumentOptionsParams.


        :param thumbnail_cpp_server_limit: The thumbnail_cpp_server_limit of this BTDocumentOptionsParams.  # noqa: E501
        :type: int
        """

        self._thumbnail_cpp_server_limit = thumbnail_cpp_server_limit

    @property
    def linked_cpp_server_limit(self):
        """Gets the linked_cpp_server_limit of this BTDocumentOptionsParams.  # noqa: E501


        :return: The linked_cpp_server_limit of this BTDocumentOptionsParams.  # noqa: E501
        :rtype: int
        """
        return self._linked_cpp_server_limit

    @linked_cpp_server_limit.setter
    def linked_cpp_server_limit(self, linked_cpp_server_limit):
        """Sets the linked_cpp_server_limit of this BTDocumentOptionsParams.


        :param linked_cpp_server_limit: The linked_cpp_server_limit of this BTDocumentOptionsParams.  # noqa: E501
        :type: int
        """

        self._linked_cpp_server_limit = linked_cpp_server_limit

    @property
    def drawing_server_memory(self):
        """Gets the drawing_server_memory of this BTDocumentOptionsParams.  # noqa: E501


        :return: The drawing_server_memory of this BTDocumentOptionsParams.  # noqa: E501
        :rtype: int
        """
        return self._drawing_server_memory

    @drawing_server_memory.setter
    def drawing_server_memory(self, drawing_server_memory):
        """Sets the drawing_server_memory of this BTDocumentOptionsParams.


        :param drawing_server_memory: The drawing_server_memory of this BTDocumentOptionsParams.  # noqa: E501
        :type: int
        """

        self._drawing_server_memory = drawing_server_memory

    @property
    def cpp_server_default_element_limit(self):
        """Gets the cpp_server_default_element_limit of this BTDocumentOptionsParams.  # noqa: E501


        :return: The cpp_server_default_element_limit of this BTDocumentOptionsParams.  # noqa: E501
        :rtype: int
        """
        return self._cpp_server_default_element_limit

    @cpp_server_default_element_limit.setter
    def cpp_server_default_element_limit(self, cpp_server_default_element_limit):
        """Sets the cpp_server_default_element_limit of this BTDocumentOptionsParams.


        :param cpp_server_default_element_limit: The cpp_server_default_element_limit of this BTDocumentOptionsParams.  # noqa: E501
        :type: int
        """

        self._cpp_server_default_element_limit = cpp_server_default_element_limit

    @property
    def cpp_server_memory(self):
        """Gets the cpp_server_memory of this BTDocumentOptionsParams.  # noqa: E501


        :return: The cpp_server_memory of this BTDocumentOptionsParams.  # noqa: E501
        :rtype: int
        """
        return self._cpp_server_memory

    @cpp_server_memory.setter
    def cpp_server_memory(self, cpp_server_memory):
        """Sets the cpp_server_memory of this BTDocumentOptionsParams.


        :param cpp_server_memory: The cpp_server_memory of this BTDocumentOptionsParams.  # noqa: E501
        :type: int
        """

        self._cpp_server_memory = cpp_server_memory

    @property
    def enable_cpp_server_memory_diagnostics(self):
        """Gets the enable_cpp_server_memory_diagnostics of this BTDocumentOptionsParams.  # noqa: E501


        :return: The enable_cpp_server_memory_diagnostics of this BTDocumentOptionsParams.  # noqa: E501
        :rtype: bool
        """
        return self._enable_cpp_server_memory_diagnostics

    @enable_cpp_server_memory_diagnostics.setter
    def enable_cpp_server_memory_diagnostics(self, enable_cpp_server_memory_diagnostics):
        """Sets the enable_cpp_server_memory_diagnostics of this BTDocumentOptionsParams.


        :param enable_cpp_server_memory_diagnostics: The enable_cpp_server_memory_diagnostics of this BTDocumentOptionsParams.  # noqa: E501
        :type: bool
        """

        self._enable_cpp_server_memory_diagnostics = enable_cpp_server_memory_diagnostics

    @property
    def extended_display_check(self):
        """Gets the extended_display_check of this BTDocumentOptionsParams.  # noqa: E501


        :return: The extended_display_check of this BTDocumentOptionsParams.  # noqa: E501
        :rtype: bool
        """
        return self._extended_display_check

    @extended_display_check.setter
    def extended_display_check(self, extended_display_check):
        """Sets the extended_display_check of this BTDocumentOptionsParams.


        :param extended_display_check: The extended_display_check of this BTDocumentOptionsParams.  # noqa: E501
        :type: bool
        """

        self._extended_display_check = extended_display_check

    @property
    def skip_retrieval_test(self):
        """Gets the skip_retrieval_test of this BTDocumentOptionsParams.  # noqa: E501


        :return: The skip_retrieval_test of this BTDocumentOptionsParams.  # noqa: E501
        :rtype: bool
        """
        return self._skip_retrieval_test

    @skip_retrieval_test.setter
    def skip_retrieval_test(self, skip_retrieval_test):
        """Sets the skip_retrieval_test of this BTDocumentOptionsParams.


        :param skip_retrieval_test: The skip_retrieval_test of this BTDocumentOptionsParams.  # noqa: E501
        :type: bool
        """

        self._skip_retrieval_test = skip_retrieval_test

    @property
    def document_memory(self):
        """Gets the document_memory of this BTDocumentOptionsParams.  # noqa: E501


        :return: The document_memory of this BTDocumentOptionsParams.  # noqa: E501
        :rtype: int
        """
        return self._document_memory

    @document_memory.setter
    def document_memory(self, document_memory):
        """Sets the document_memory of this BTDocumentOptionsParams.


        :param document_memory: The document_memory of this BTDocumentOptionsParams.  # noqa: E501
        :type: int
        """

        self._document_memory = document_memory

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BTDocumentOptionsParams):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Onshape REST API

    The Onshape REST API consumed by all clients.  # noqa: E501

    OpenAPI spec version: 1.96
    Contact: api-support@onshape.zendesk.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six


class Info(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'title': 'str',
        'description': 'str',
        'terms_of_service': 'str',
        'contact': 'Contact',
        'license': 'License',
        'version': 'str',
        'extensions': 'dict(str, object)'
    }

    attribute_map = {
        'title': 'title',
        'description': 'description',
        'terms_of_service': 'termsOfService',
        'contact': 'contact',
        'license': 'license',
        'version': 'version',
        'extensions': 'extensions'
    }

    def __init__(self, title=None, description=None, terms_of_service=None, contact=None, license=None, version=None, extensions=None):  # noqa: E501
        """Info - a model defined in OpenAPI"""  # noqa: E501

        self._title = None
        self._description = None
        self._terms_of_service = None
        self._contact = None
        self._license = None
        self._version = None
        self._extensions = None
        self.discriminator = None

        if title is not None:
            self.title = title
        if description is not None:
            self.description = description
        if terms_of_service is not None:
            self.terms_of_service = terms_of_service
        if contact is not None:
            self.contact = contact
        if license is not None:
            self.license = license
        if version is not None:
            self.version = version
        if extensions is not None:
            self.extensions = extensions

    @property
    def title(self):
        """Gets the title of this Info.  # noqa: E501


        :return: The title of this Info.  # noqa: E501
        :rtype: str
        """
        return self._title

    @title.setter
    def title(self, title):
        """Sets the title of this Info.


        :param title: The title of this Info.  # noqa: E501
        :type: str
        """

        self._title = title

    @property
    def description(self):
        """Gets the description of this Info.  # noqa: E501


        :return: The description of this Info.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this Info.


        :param description: The description of this Info.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def terms_of_service(self):
        """Gets the terms_of_service of this Info.  # noqa: E501


        :return: The terms_of_service of this Info.  # noqa: E501
        :rtype: str
        """
        return self._terms_of_service

    @terms_of_service.setter
    def terms_of_service(self, terms_of_service):
        """Sets the terms_of_service of this Info.


        :param terms_of_service: The terms_of_service of this Info.  # noqa: E501
        :type: str
        """

        self._terms_of_service = terms_of_service

    @property
    def contact(self):
        """Gets the contact of this Info.  # noqa: E501


        :return: The contact of this Info.  # noqa: E501
        :rtype: Contact
        """
        return self._contact

    @contact.setter
    def contact(self, contact):
        """Sets the contact of this Info.


        :param contact: The contact of this Info.  # noqa: E501
        :type: Contact
        """

        self._contact = contact

    @property
    def license(self):
        """Gets the license of this Info.  # noqa: E501


        :return: The license of this Info.  # noqa: E501
        :rtype: License
        """
        return self._license

    @license.setter
    def license(self, license):
        """Sets the license of this Info.


        :param license: The license of this Info.  # noqa: E501
        :type: License
        """

        self._license = license

    @property
    def version(self):
        """Gets the version of this Info.  # noqa: E501


        :return: The version of this Info.  # noqa: E501
        :rtype: str
        """
        return self._version

    @version.setter
    def version(self, version):
        """Sets the version of this Info.


        :param version: The version of this Info.  # noqa: E501
        :type: str
        """

        self._version = version

    @property
    def extensions(self):
        """Gets the extensions of this Info.  # noqa: E501


        :return: The extensions of this Info.  # noqa: E501
        :rtype: dict(str, object)
        """
        return self._extensions

    @extensions.setter
    def extensions(self, extensions):
        """Sets the extensions of this Info.


        :param extensions: The extensions of this Info.  # noqa: E501
        :type: dict(str, object)
        """

        self._extensions = extensions

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Info):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Onshape REST API

    The Onshape REST API consumed by all clients.  # noqa: E501

    OpenAPI spec version: 1.96
    Contact: api-support@onshape.zendesk.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from onshape_client.api_client import ApiClient


class PartsApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def get_parts_wmv(self, did, wvm, wvmid, **kwargs):  # noqa: E501
        """Get list of parts  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_parts_wmv(did, wvm, wvmid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str did: Document ID. (required)
        :param str wvm: One of w or v or m corresponding to whether a workspace or version or microversion was entered. (required)
        :param str wvmid: Workspace (w), Version (v) or Microversion (m) ID. (required)
        :param str element_id: Element ID
        :param bool with_thumbnails: Whether or not to include thumbnails (not supported for microversion)
        :param bool include_property_defaults: If true, include metadata schema property defaults in response
        :param str link_document_id: Id of document that links to the document being accessed. This may provide additional access rights to the document. Allowed only with version (v) path parameter.
        :param str configuration: Configuration string.
        :return: list[BTPartMetadataInfo]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_parts_wmv_with_http_info(did, wvm, wvmid, **kwargs)  # noqa: E501
        else:
            (data) = self.get_parts_wmv_with_http_info(did, wvm, wvmid, **kwargs)  # noqa: E501
            return data

    def get_parts_wmv_with_http_info(self, did, wvm, wvmid, **kwargs):  # noqa: E501
        """Get list of parts  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_parts_wmv_with_http_info(did, wvm, wvmid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str did: Document ID. (required)
        :param str wvm: One of w or v or m corresponding to whether a workspace or version or microversion was entered. (required)
        :param str wvmid: Workspace (w), Version (v) or Microversion (m) ID. (required)
        :param str element_id: Element ID
        :param bool with_thumbnails: Whether or not to include thumbnails (not supported for microversion)
        :param bool include_property_defaults: If true, include metadata schema property defaults in response
        :param str link_document_id: Id of document that links to the document being accessed. This may provide additional access rights to the document. Allowed only with version (v) path parameter.
        :param str configuration: Configuration string.
        :return: list[BTPartMetadataInfo]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['did', 'wvm', 'wvmid', 'element_id', 'with_thumbnails', 'include_property_defaults', 'link_document_id', 'configuration']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_parts_wmv" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'did' is set
        if ('did' not in local_var_params or
                local_var_params['did'] is None):
            raise ValueError("Missing the required parameter `did` when calling `get_parts_wmv`")  # noqa: E501
        # verify the required parameter 'wvm' is set
        if ('wvm' not in local_var_params or
                local_var_params['wvm'] is None):
            raise ValueError("Missing the required parameter `wvm` when calling `get_parts_wmv`")  # noqa: E501
        # verify the required parameter 'wvmid' is set
        if ('wvmid' not in local_var_params or
                local_var_params['wvmid'] is None):
            raise ValueError("Missing the required parameter `wvmid` when calling `get_parts_wmv`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'did' in local_var_params:
            path_params['did'] = local_var_params['did']  # noqa: E501
        if 'wvm' in local_var_params:
            path_params['wvm'] = local_var_params['wvm']  # noqa: E501
        if 'wvmid' in local_var_params:
            path_params['wvmid'] = local_var_params['wvmid']  # noqa: E501

        query_params = []
        if 'element_id' in local_var_params:
            query_params.append(('elementId', local_var_params['element_id']))  # noqa: E501
        if 'with_thumbnails' in local_var_params:
            query_params.append(('withThumbnails', local_var_params['with_thumbnails']))  # noqa: E501
        if 'include_property_defaults' in local_var_params:
            query_params.append(('includePropertyDefaults', local_var_params['include_property_defaults']))  # noqa: E501
        if 'link_document_id' in local_var_params:
            query_params.append(('linkDocumentId', local_var_params['link_document_id']))  # noqa: E501
        if 'configuration' in local_var_params:
            query_params.append(('configuration', local_var_params['configuration']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/vnd.onshape.v1+json;charset=UTF-8; qs=0.1', 'application/json;charset=UTF-8; qs=0.9'])  # noqa: E501

        # Authentication setting
        auth_settings = ['OAuth2']  # noqa: E501

        return self.api_client.call_api(
            '/api/parts/d/{did}/{wvm}/{wvmid}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[BTPartMetadataInfo]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_parts_wmve(self, did, wvm, wvmid, eid, **kwargs):  # noqa: E501
        """Get parts from an element.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_parts_wmve(did, wvm, wvmid, eid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str did: Document ID. (required)
        :param str wvm: One of w or v or m corresponding to whether a workspace or version or microversion was entered. (required)
        :param str wvmid: Workspace (w), Version (v) or Microversion (m) ID. (required)
        :param str eid: Element ID. (required)
        :param bool with_thumbnails: Whether or not to include thumbnails (not supported for microversion)
        :param bool include_property_defaults: If true, include metadata schema property defaults in response
        :param str configuration: Configuration string.
        :param str link_document_id: Id of document that links to the document being accessed. This may provide additional access rights to the document. Allowed only with version (v) path parameter.
        :return: list[BTPartMetadataInfo]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_parts_wmve_with_http_info(did, wvm, wvmid, eid, **kwargs)  # noqa: E501
        else:
            (data) = self.get_parts_wmve_with_http_info(did, wvm, wvmid, eid, **kwargs)  # noqa: E501
            return data

    def get_parts_wmve_with_http_info(self, did, wvm, wvmid, eid, **kwargs):  # noqa: E501
        """Get parts from an element.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_parts_wmve_with_http_info(did, wvm, wvmid, eid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str did: Document ID. (required)
        :param str wvm: One of w or v or m corresponding to whether a workspace or version or microversion was entered. (required)
        :param str wvmid: Workspace (w), Version (v) or Microversion (m) ID. (required)
        :param str eid: Element ID. (required)
        :param bool with_thumbnails: Whether or not to include thumbnails (not supported for microversion)
        :param bool include_property_defaults: If true, include metadata schema property defaults in response
        :param str configuration: Configuration string.
        :param str link_document_id: Id of document that links to the document being accessed. This may provide additional access rights to the document. Allowed only with version (v) path parameter.
        :return: list[BTPartMetadataInfo]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['did', 'wvm', 'wvmid', 'eid', 'with_thumbnails', 'include_property_defaults', 'configuration', 'link_document_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_parts_wmve" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'did' is set
        if ('did' not in local_var_params or
                local_var_params['did'] is None):
            raise ValueError("Missing the required parameter `did` when calling `get_parts_wmve`")  # noqa: E501
        # verify the required parameter 'wvm' is set
        if ('wvm' not in local_var_params or
                local_var_params['wvm'] is None):
            raise ValueError("Missing the required parameter `wvm` when calling `get_parts_wmve`")  # noqa: E501
        # verify the required parameter 'wvmid' is set
        if ('wvmid' not in local_var_params or
                local_var_params['wvmid'] is None):
            raise ValueError("Missing the required parameter `wvmid` when calling `get_parts_wmve`")  # noqa: E501
        # verify the required parameter 'eid' is set
        if ('eid' not in local_var_params or
                local_var_params['eid'] is None):
            raise ValueError("Missing the required parameter `eid` when calling `get_parts_wmve`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'did' in local_var_params:
            path_params['did'] = local_var_params['did']  # noqa: E501
        if 'wvm' in local_var_params:
            path_params['wvm'] = local_var_params['wvm']  # noqa: E501
        if 'wvmid' in local_var_params:
            path_params['wvmid'] = local_var_params['wvmid']  # noqa: E501
        if 'eid' in local_var_params:
            path_params['eid'] = local_var_params['eid']  # noqa: E501

        query_params = []
        if 'with_thumbnails' in local_var_params:
            query_params.append(('withThumbnails', local_var_params['with_thumbnails']))  # noqa: E501
        if 'include_property_defaults' in local_var_params:
            query_params.append(('includePropertyDefaults', local_var_params['include_property_defaults']))  # noqa: E501
        if 'configuration' in local_var_params:
            query_params.append(('configuration', local_var_params['configuration']))  # noqa: E501
        if 'link_document_id' in local_var_params:
            query_params.append(('linkDocumentId', local_var_params['link_document_id']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/vnd.onshape.v1+json;charset=UTF-8; qs=0.1', 'application/json;charset=UTF-8; qs=0.9'])  # noqa: E501

        # Authentication setting
        auth_settings = ['OAuth2']  # noqa: E501

        return self.api_client.call_api(
            '/api/parts/d/{did}/{wvm}/{wvmid}/e/{eid}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[BTPartMetadataInfo]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def update_parts_wmv(self, did, wvm, wvmid, **kwargs):  # noqa: E501
        """Part metadata batch update.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_parts_wmv(did, wvm, wvmid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str did: Document ID. (required)
        :param str wvm: One of w or v or m corresponding to whether a workspace or version or microversion was entered. (required)
        :param str wvmid: Workspace (w), Version (v) or Microversion (m) ID. (required)
        :param str edit_description: Description of the update (as appear in document history)
        :param str body:
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.update_parts_wmv_with_http_info(did, wvm, wvmid, **kwargs)  # noqa: E501
        else:
            (data) = self.update_parts_wmv_with_http_info(did, wvm, wvmid, **kwargs)  # noqa: E501
            return data

    def update_parts_wmv_with_http_info(self, did, wvm, wvmid, **kwargs):  # noqa: E501
        """Part metadata batch update.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_parts_wmv_with_http_info(did, wvm, wvmid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str did: Document ID. (required)
        :param str wvm: One of w or v or m corresponding to whether a workspace or version or microversion was entered. (required)
        :param str wvmid: Workspace (w), Version (v) or Microversion (m) ID. (required)
        :param str edit_description: Description of the update (as appear in document history)
        :param str body:
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['did', 'wvm', 'wvmid', 'edit_description', 'body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method update_parts_wmv" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'did' is set
        if ('did' not in local_var_params or
                local_var_params['did'] is None):
            raise ValueError("Missing the required parameter `did` when calling `update_parts_wmv`")  # noqa: E501
        # verify the required parameter 'wvm' is set
        if ('wvm' not in local_var_params or
                local_var_params['wvm'] is None):
            raise ValueError("Missing the required parameter `wvm` when calling `update_parts_wmv`")  # noqa: E501
        # verify the required parameter 'wvmid' is set
        if ('wvmid' not in local_var_params or
                local_var_params['wvmid'] is None):
            raise ValueError("Missing the required parameter `wvmid` when calling `update_parts_wmv`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'did' in local_var_params:
            path_params['did'] = local_var_params['did']  # noqa: E501
        if 'wvm' in local_var_params:
            path_params['wvm'] = local_var_params['wvm']  # noqa: E501
        if 'wvmid' in local_var_params:
            path_params['wvmid'] = local_var_params['wvmid']  # noqa: E501

        query_params = []
        if 'edit_description' in local_var_params:
            query_params.append(('editDescription', local_var_params['edit_description']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in local_var_params:
            body_params = local_var_params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/vnd.onshape.v1+json;charset=UTF-8; qs=0.1', 'application/json;charset=UTF-8; qs=0.9'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json;charset=UTF-8'])  # noqa: E501

        # Authentication setting
        auth_settings = ['OAuth2']  # noqa: E501

        return self.api_client.call_api(
            '/api/parts/d/{did}/{wvm}/{wvmid}', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)
